refactoring

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Patterns map[string]Pattern

Patterns is a map from smell name to refactoring pattern.

Functions

func ListPatterns

func ListPatterns() []string

ListPatterns returns all available pattern names.

Types

type Pattern

type Pattern struct {
	Name        string
	Description string
	Content     string // full markdown
}

Pattern represents a refactoring strategy.

func Lookup

func Lookup(smellName string) *Pattern

Lookup returns the refactoring pattern for a given smell, or nil.

Jump to